==> haskell-crypto-api-tests-0.3-189-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-api-tests
version:              0.3
visibility:           public
id:                   crypto-api-tests-0.3-EDg4sSyxM4wHeEtfJm2O5d
key:                  crypto-api-tests-0.3-EDg4sSyxM4wHeEtfJm2O5d
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             http://trac.haskell.org/crypto-api/wiki
synopsis:             A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).

category:             Data, Cryptography
abi:                  efe29da74c00338686a790cda7373da1
exposed:              True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish

hidden-modules:       Paths_crypto_api_tests
import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypto-api-tests-0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-api-tests
hs-libraries:         HScrypto-api-tests-0.3-EDg4sSyxM4wHeEtfJm2O5d
depends:
    HUnit-1.6.2.0-C1iPOmv2pdMIa65hP6dNHl
    QuickCheck-2.14.2-CbbtdECldQDI2rMaygQqRk base-4.15.1.0
    bytestring-0.10.12.1 cereal-0.5.8.2-3mqeMFbPDR59NtNSFrV4h3
    crypto-api-0.13.3-BF7h8F67L4j3wIvu9guSXU directory-1.3.6.2
    filepath-1.4.2.1 test-framework-0.8.2.0-G58OQhfX3rsKWww5N5hKls
    test-framework-hunit-0.3.0.2-1ebO3JKTTc2FzNqcRy251A
    test-framework-quickcheck2-0.3.0.5-9eurXImUyKNGtCw7IdmjJB

haddock-interfaces:
    /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock

haddock-html:         /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-tests-0.3-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypto-api-tests.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypto-api-tests
version:              0.3
visibility:           public
id:                   crypto-api-tests-0.3-CNt9QalPmpEL5M0EW4Muo4
key:                  crypto-api-tests-0.3-CNt9QalPmpEL5M0EW4Muo4
license:              BSD-3-Clause
copyright:            Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer:           Thomas DuBuisson <thomas.dubuisson@gmail.com>
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
homepage:             http://trac.haskell.org/crypto-api/wiki
synopsis:             A test framework and KATs for cryptographic operations.
description:
    A test framework for hash and cipher operations using
    the crypto-api interface.  Known answer tests (KATs)
    for common cryptographic algorithms are included.
    Patches welcome (both adding KATs for more algorithms
    or property tests for classes of algorithms).

category:             Data, Cryptography
abi:                  9ceaed83dfa8061a5c9ab8fabfe583a7
exposed:              True
exposed-modules:
    Test.AES Test.Crypto Test.HMAC Test.MD5 Test.ParseNistKATs Test.SHA
    Test.TwoFish

hidden-modules:       Paths_crypto_api_tests
import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypto-api-tests-0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypto-api-tests-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypto-api-tests
hs-libraries:         HScrypto-api-tests-0.3-CNt9QalPmpEL5M0EW4Muo4
depends:
    HUnit-1.6.2.0-C1iPOmv2pdMIa65hP6dNHl
    QuickCheck-2.14.2-2d1sNWCQrBtBwhjNiSfZuE base-4.15.1.0
    bytestring-0.10.12.1 cereal-0.5.8.2-3mqeMFbPDR59NtNSFrV4h3
    crypto-api-0.13.3-BF7h8F67L4j3wIvu9guSXU directory-1.3.6.2
    filepath-1.4.2.1 test-framework-0.8.2.0-8RNFEzTOY4QGiIvrDcgG6U
    test-framework-hunit-0.3.0.2-2WtElWya0SOFx4qJuxXdqx
    test-framework-quickcheck2-0.3.0.5-BRxDlhi2e2G3snqA0qIFsz

haddock-interfaces:
    /usr/share/doc/haskell-crypto-api-tests/html/crypto-api-tests.haddock

haddock-html:         /usr/share/doc/haskell-crypto-api-tests/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
